#[repr(u8)]pub enum ChachaDinByteOrder {
DEFAULT = 0,
REVERSE = 1,
}Variants
DEFAULT = 0
Use default byte order within each input word, where bytes are ordered as follows: B0, B1, B2, B3.
REVERSE = 1
Reverse the byte order within each input word, where bytes are re-ordered as follows: B3, B2, B1, B0.
Implementations